#!/bin/bash

# Redirect stdout to system.log
exec >> /home/tasc/crest/log/system.log
exec 3>&1

# Redirect stderr to stdout  (2>&1)
exec 4>&2 2>&1

echo "============================================================================================"
echo "Peak - System Initialization"
echo "  Version 1.0.0 - March 2, 2016"
echo "  (c) TASC Systems Inc."
echo "--------------------------------------------------------------------------------------------"
date
echo

# Confirm that the user has privilege to run this setup script
echo "--- Checking user privilige"
if [ $EUID -ne 0 ]
  then echo "   Exiting! Please re-run as priviliged user"
  exit
fi
echo "   OK, running with sufficient privileges"
echo

# Read system configuration from Peak config file
echo "--- Reading peak.config file to determine configuration requirements ..."
source /home/tasc/crest/peak.config
echo "   Digital Outputs Location           : $DigitalOutputsLocation"
echo "   Digital Outputs Count              : $DigitalOutputsCount"
echo
echo "   Analog Inputs Count                : $AnalogInputsCount"
echo "   Analog Inputs Config - Unipolar    : $AnalogInputsConfigUnipolar"
echo "   Analog Inputs Config - SingleEnded : $AnalogInputsConfigSingleEnded"
echo
echo "   Default LED GPIO                   : $DefaultLedGpioLocation"
echo

# Processing LED GPIO
echo "--- Processing LED GPIO"
cd /sys/class/gpio
CWD=$(pwd)
echo "  Changing to $CWD to process LED (GPIO$DefaultLedGpioLocation)"
echo $DefaultLedGpioLocation > export
echo "  Changing to $CWD/gpio$DefaultLedGpioLocation to set direction (out) and value (1)"
cd $CWD/gpio$DefaultLedGpioLocation
echo out > $CWD/gpio$DefaultLedGpioLocation/direction
echo 1 > $CWD/gpio$DefaultLedGpioLocation/value

echo "  LED to blue blinking state to indicate up and running"
cd /sys/class/leds
CWD=$(pwd)
echo none > $CWD/led:red/trigger
echo none > $CWD/led:green/trigger
echo none > $CWD/led:blue/trigger
echo 0 > $CWD/led:red/brightness
echo 0 > $CWD/led:green/brightness
echo 1 > $CWD/led:blue/brightness
echo

# Processing Analog Inputs
echo "--- Processing Analog Inputs"
cd /sys/class/hwmon/hwmon0
CWD=$(pwd)
echo "  Changing to $CWD to process Analog Inputs"

# Configure the Analog Inputs
AnalogInputsChipConfigFile='chip_conf'
echo "    Setting configuration for LTC2309 chip at $AnalogInputsChipConfigFile (Unipolar Configuration value=$AnalogInputsConfigUnipolar)"
echo $AnalogInputsConfigUnipolar > $AnalogInputsChipConfigFile

IOCOUNTER=0
while [ $IOCOUNTER -lt $AnalogInputsCount ]; do
	# Configure the input points for the LTC2309
	#		1=single-ended, 0=differential
	AnalogInputsConfigFile="in"$IOCOUNTER"_conf"
	echo "    Configuring analog input chip at $AnalogInputsConfigFile (Single-Ended Configuration value=$AnalogInputsConfigSingleEnded)"
	echo $AnalogInputsConfigSingleEnded > $AnalogInputsConfigFile

	let IOCOUNTER=IOCOUNTER+1
	sleep 0.1
done
echo

# Processing Digital Outputs
echo "--- Processing Digital Outputs"
cd /sys/class/gpio
CWD=$(pwd)
echo "  Changing to $CWD to process Digital Outputs"

# Processing Digital Outputs
echo "  Processing Digital Outputs"
IOCOUNTER=0
IOBASE=$DigitalOutputsLocation
while [ $IOCOUNTER -lt $DigitalOutputsCount ]; do
	let IOLOCATION=$IOBASE+$IOCOUNTER
	echo "      Exporting Digital Output $IOLOCATION"
	echo $IOLOCATION > export

	echo "      Setting Digital Output gpio$IOLOCATION/direction to out"
	echo out > gpio$IOLOCATION/direction
		echo "      Setting Digital Output gpio$IOLOCATION/value to 0"
	echo 0 > gpio$IOLOCATION/value

	let IOCOUNTER=IOCOUNTER+1
	sleep 0.1
done
echo

# Mute & Unmute audio lines
echo "--- Setting mixer mutes/unmutes"
amixer set 'Left PGA Mixer Mic2L' unmute
amixer set 'Left PGA Mixer Mic2R' unmute
amixer set 'Right PGA Mixer Mic2L' unmute
amixer set 'Right PGA Mixer Mic2R' unmute

amixer set 'Left PGA Mixer Line1L' mute
amixer set 'Left PGA Mixer Line1R' mute
amixer set 'Right PGA Mixer Line1L' mute
amixer set 'Right PGA Mixer Line1R' mute

# Start node app.js
echo "--- Starting Peak Administration Application"
cd /home/tasc/crest
CWD=$(pwd)

# Ensure that the log directory is there
mkdir log

# Turn off redirection, to allow forever app write to the system.log file
#exec 1>&3 3>&-
#exec 2>&4 4>&-

# Setup the forever and node directories
NODE_BIN_DIR=/usr/local/bin
NODE_PATH=/home/tasc/crest/node_modules/
APPLICATION_DIRECTORY=/home/tasc/crest
APPLICATION_START=app.js
PIDFILE=/var/run/$NAME.pid
LOGFILE=/var/log/$NAME.log
 
PATH=$NODE_BIN_DIR:$PATH
export NODE_PATH=$NODE_PATH

# Start the Crest application for Peak
echo "  Starting the Crest app for Peak using the '/usr/local/bin/node app.js' command"
#/usr/local/bin/forever -v -w --pidFile PeakApp --watchIgnore '{log,data,node_modules}' --sourceDir $APPLICATION_DIRECTORY start $APPLICATION_START
/usr/local/bin/node app.js
